// Copyright 2007 by Intuit Inc.
// All rights reserved
// Usage governed by the QuickBooks SDK Developer's License Agreement

using System;
using System.Collections.Generic;
using System.Text;
using Interop.QBFC10;

namespace Intuit_QBFC1.Subscription_Framework.Menu
{
    public class MenuItemType : IMenuBuilder
    {
        private string _menuText;
        private string _eventTag;
        private ENVisibleIf[] _visibleIf = new ENVisibleIf[0];
        private ENVisibleIfNot[] _visibleIfNot = new ENVisibleIfNot[0];
        private ENEnabledIf[] _enableIf = new ENEnabledIf[0];
        private ENEnabledIfNot[] _enableIfNot = new ENEnabledIfNot[0];

        // Don't allow calls to the default constructor
        private MenuItemType() { }

        /// <summary>
        /// An object that defines a single menu item
        /// </summary>
        /// <param name="menuText">The string that appears in the QuickBooks menu</param>
        /// <param name="eventTag">Returned in the EventTag element of the UIExtensionEvent aggregate in the QBXMLEvents message</param>
        public MenuItemType(string menuText, string eventTag)
        {
            if (menuText.Length == 0)
                throw new Exception("Error: MenuText must be provided!");
            if (eventTag.Length == 0)
                throw new Exception("Error: An EventTag must be provided!");

            _menuText = menuText;
            _eventTag = eventTag;
        }

        /// <summary>
        /// Allows querying of the MenuText property.  Setting must be done in the constructor
        /// </summary>
        public string MenuText
        {
            get
            {
                return _menuText;
            }
        }

        /// <summary>
        /// Allows querying of the EventTag property.  Setting must be done in the constructor
        /// </summary>
        public string EventTag
        {
            get
            {
                return _eventTag;
            }
        }

        /// <summary>
        /// Allows setting and getting of the VisibleIF condition
        /// </summary>
        public ENVisibleIf[] VisibleIf
        {
            get
            {
                return _visibleIf;
            }
            set
            {
                _visibleIf = value;
            }
        }

        /// <summary>
        /// Allows setting and getting of the Visible IF NOT condition
        /// </summary>
        public ENVisibleIfNot[] VisibleIfNot
        {
            get
            {
                return _visibleIfNot;
            }
            set
            {
                _visibleIfNot = value;
            }
        }

        /// <summary>
        /// Allows setting and getting of the Enable IF condition
        /// </summary>
        public ENEnabledIf[] EnabledIf
        {
            get
            {
                return _enableIf;
            }
            set
            {
                _enableIf = value;
            }
        }

        /// <summary>
        /// Allows setting and getting of the Enable IF NOT condition
        /// </summary>
        public ENEnabledIfNot[] EnabledIfNot
        {
            get
            {
                return _enableIfNot;
            }
            set
            {
                _enableIfNot = value;
            }
        }
    }
}
